import os
import glob 
from stat import *

import opusutil
import hst_missionquery
import hst_archdbquery

from rm_DatasetList import *
from rm_FileList import *
from rm_Mission import *

class rm_FuseMission (rm_Mission):
  """Request Manager class for Fuse mission-specific functions

  """
  def __init__(self, name):
    """
=====================================================================
Name: rm_FuseMission.__init__

Description:
------------
The constructor for a rm_FuseMission object sets the mission name and
fills the archive_class_map and valid_extensions.

Assumes these environment variables are defined:
OPUS_SERVER - name of mission database server
OPUS_DB - name of mission database

Inputs:
------------------
name - name of the mission

Members:
---------
translate_extension

History:
--------
01/09/04 49551 MSwam     first version
07/15/10 57271 MSwam     remove db retry parameter

=====================================================================
    """
    # call Superclass constructor
    #
    rm_Mission.__init__(self, name)
   
    # create database object for the mission database
    self._dbobj = hst_missionquery.HST_Mission_db(os.environ['OPUS_SERVER'],
                                                  os.environ['OPUS_DB'])

    # create database object for the archive database
    self._arch_dbobj = hst_archdbquery.HST_Arch_db(os.environ['ARCH_SERVER'],
                                                  os.environ['ARCH_DB'])

    # fill the archive class map and valid extensions
    self._archive_class_map = self._dbobj.get_archive_class_map()
    self._valid_extensions = self._dbobj.get_valid_extensions()


  def translate_extension(self, dataset_name, longext, product_long_ext,
                          exposure_long_ext):
    """
===========================================================================
Name: rm_FuseMission.translate_extension

Description:
------------
For FUSE, the passed long extension is converted into a short extension
using a lookup into either the product or exposure long extension map.
The dataset_name is used to decide whether the product or exposure
translation form is used.

Inputs:
-------
dataset_name
longext - long file extension
product_long_ext - the product long extension map, keyed on long extension
exposure_long_ext - the exposure long extension map, keyed on long extension

Exceptions:
-------------
FailedEXTTranslation - if dataset name is not valid
History:
--------
03/18/04 49551 MSwam     first version
04/20/04 50823 MSwam     don't translate "fit" extension (for fur class)
===========================================================================
    """
    if longext == "fit":
      # do not translate this extension (used in fur class data)
      return "fit"
    elif len(dataset_name) < 11:
      # cannot be translated
      opusutil.PrintMsg("E","translate_extension: name too short for "+
                            "translation: "+dataset_name)
      raise CannotTranslateDatasetName
    elif dataset_name[8:11] == "000":
      # use the product translation
      ext = product_long_ext[longext]
    else:
      # use the exposure translation
      ext = exposure_long_ext[longext]
    #
    return ext


  def load_ingest_data_set_info(self, dataset, data_id, generation_date,
                                dataset_list, mission, irc_data_source):
    """
===========================================================================

Name: load_ingest_data_set_info

Purpose: Loads the ingest_data_set_info table with rows for each
         dataset.

Inputs:
  dataset
  data_id
  generation_date
  dataset_list
  mission
  irc_data_source

History:
-------- -----  --------  --------------------------------------
01/07/04 49551  MSwam     first version
03/23/04 50823  MSwam     replace pipeline_source with data_source
04/14/04 50823  MSwam     only write db entries for present datasets
04/16/04 50823  J.Baum    remove time_now argument in this method and
                          in insert_data_set_info
01/04/08 59094  MSwam     Move from SHARE to mission code
===========================================================================
    """
    # insert a row for each present dataset
    for d in dataset_list:
      if d._present:
        self._arch_dbobj.insert_ingest_data_set_info(data_id, dataset,
                              generation_date, d._archive_class_name,
                              d._dataset_name, mission,
                              d._dads_request_id,
                              irc_data_source,
                              d._install_dir, d._file_count)
    #
    return


#========================================================================
# TEST 
#========================================================================
if __name__ == "__main__":
  a = rm_FuseMission("FUSE",3600)
  opusutil.PrintMsg("I","done")
